"""Users (principals) for the WAeUP portal.
"""
import grok
from hurry import yui
from waeup.authentication import Account
from waeup.interfaces import IUserContainer, IUserAccount
from waeup.viewlets import LeftSidebar, MainArea, Index, Manage, FormWrapMixin

class UserContainer(grok.Container):
    """A container for principals.

    See interfaces.py and users.txt for extensive description.
    """
    grok.implements(IUserContainer)
    grok.require('waeup.manageUsers')

    def addUser(self, name, password, title=None, description=None):
        if title is None:
            title = name
        if description is None:
            description = title
        self[name] = Account(name, password, title, description)

    def addAccount(self, account):
        self[account.name] = account
        
    def delUser(self, name):
        if name in self.keys():
            del self[name]

class UserContainerView(Index):
    grok.require('waeup.manageUsers')
    grok.context(IUserContainer)
    grok.name('index')
    
    def update(self, userid=None, adduser=None, edit=None, delete=None):
        yui.sam.need()
        yui.datatable.need()

        if edit is not None and userid is not None:
            self.redirect(self.url(userid))
        
    def render(self, *args, **kw):
        return super(UserContainerView, self).render(*args, **kw)
    
class UserContainerMain(grok.Viewlet):
    grok.require('waeup.manageUsers')
    grok.viewletmanager(MainArea)
    grok.template('usermain')
    grok.view(UserContainerView)


class UserEditForm(grok.EditForm):
    grok.context(IUserAccount)
    form_fields = grok.AutoFields(IUserAccount)
    grok.require('waeup.manageUsers')    

    @grok.action('Save')
    def save(self, **data):
        self.applyData(self.context, **data)
        self.flash('User was modified.')
        return
    
    @grok.action('Save and return')
    def saveAndReturn(self, **data):
        self.applyData(self.context, **data)
        self.flash('User was modified.')
        self.redirect(self.url(self.context.__parent__))
        return

    @grok.action('Cancel')
    def cancel(self, **data):
        self.redirect(self.url(self.context.__parent__))
        return


class UserEditMain(FormWrapMixin, grok.Viewlet):
    """A viewlet that renders the `UserEditForm`.
    """
    grok.viewletmanager(MainArea)
    grok.context(IUserAccount)
    grok.view(Index)
    grok.require('waeup.manageUsers')
    
    formview_name = 'usereditform' # The name of the formview we want to
                                   # be rendered in this viewlet.
